EventItem class

Constructors

EventItem({required String title, required DateTime date, required TimeOfDay time, required String location, required String description})

Properties

date DateTime
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time TimeOfDay
getter/setter pair
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited