Book class

Constructors

Book({int? id, required String title, required String author, required String category, required String description})
Book.fromMap(Map<String, dynamic> map)
factory

Properties

author String
final
category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited