newsList property

List<News> newsList
final

Implementation

final List<News> newsList = [
  News(
    title: 'AI is transforming the tech industry',
    description:
        'Artificial Intelligence is rapidly changing industries by automating processes, improving efficiency, and enabling new innovations.',
  ),
  News(
    title: 'Flutter 4.0 Released',
    description:
        'Flutter 4.0 introduces improved performance, better UI tools, and enhanced developer experience.',
  ),
  News(
    title: 'SpaceX launches new rocket',
    description:
        'SpaceX successfully launched its latest rocket, marking another milestone in space exploration.',
  ),
  News(
    title: 'Climate change concerns rise globally',
    description:
        'Global leaders are emphasizing the need for urgent action to combat climate change.',
  ),
  News(
    title: 'Stock markets show positive growth',
    description:
        'Markets are experiencing steady growth as investors gain confidence in economic recovery.',
  ),
];