menu
ssn package
documentation
ai/ai_calculator_app.dart
Parser class
Parser class
dark_mode
light_mode
Parser
class
Constructors
Parser
(
String
s
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
i
↔
int
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
s
→
String
final
Methods
factor
(
)
→
double
match
(
String
c
)
→
bool
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse
(
)
→
double
term
(
)
→
double
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
ssn package
documentation
ai/ai_calculator_app
Parser class
ai_calculator_app library